SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema todo
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `todo` DEFAULT CHARACTER SET latin1 ;
USE `todo` ;

-- -----------------------------------------------------
-- Table `todo`.`USER`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`USER` (
  `ID_USER` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `EMAIL` VARCHAR(255) NOT NULL,
  `PASSWORD` VARCHAR(255) NOT NULL,
  `REGISTRATION_DATE` DATETIME NOT NULL,
  `LAST_LOGIN` DATETIME NOT NULL,
  `ACCOUNT_NON_EXPIRED` BIT(1) NOT NULL,
  `ACCOUNT_NON_LOCKED` BIT(1) NOT NULL,
  `CREDENTIALS_NON_EXPIRED` BIT(1) NOT NULL,
  `ENABLED` BIT(1) NOT NULL,
  PRIMARY KEY (`ID_USER`),
  UNIQUE INDEX `USER_ID_UNIQUE` (`ID_USER` ASC),
  UNIQUE INDEX `EMAIL_UNIQUE` (`EMAIL` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `todo`.`TASK`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`TASK` (
  `ID_TASK` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(200) NOT NULL,
  `DESCRIPTION` VARCHAR(250) NULL DEFAULT NULL,
  `STATUS` VARCHAR(45) NULL DEFAULT NULL,
  PRIMARY KEY (`ID_TASK`),
  UNIQUE INDEX `TASK_ID_UNIQUE` (`ID_TASK` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `todo`.`FILE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`FILE` (
  `ID_FILE` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `ID_TASK` BIGINT(20) NOT NULL,
  `ID_USER` BIGINT(20) NOT NULL,
  `FILE_NAME` VARCHAR(1000) NOT NULL,
  `FILE_ITEM` MEDIUMBLOB NOT NULL,
  `INSERT_DATE` DATETIME NOT NULL,
  `DELETED_FLAG` BIT(1) NULL DEFAULT NULL,
  `CONTENT_TYPE` VARCHAR(200) NULL DEFAULT NULL,
  PRIMARY KEY (`ID_FILE`, `ID_USER`, `ID_TASK`),
  INDEX `FK_USER_ID_idx` (`ID_USER` ASC),
  INDEX `FK_TASK_ID_idx` (`ID_TASK` ASC),
  CONSTRAINT `FK_USER_ID`
    FOREIGN KEY (`ID_USER`)
    REFERENCES `todo`.`USER` (`ID_USER`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_TASK_ID`
    FOREIGN KEY (`ID_TASK`)
    REFERENCES `todo`.`TASK` (`ID_TASK`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `todo`.`NOTE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`NOTE` (
  `ID_NOTE` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `ID_TASK` BIGINT(20) NOT NULL,
  `ID_USER` BIGINT(20) NOT NULL,
  `NOTE` VARCHAR(200) NOT NULL,
  `INSERT_DATE` DATETIME NOT NULL,
  PRIMARY KEY (`ID_NOTE`, `ID_USER`, `ID_TASK`),
  INDEX `id_note_user_idx` (`ID_USER` ASC),
  INDEX `id_note_task_idx` (`ID_TASK` ASC),
  CONSTRAINT `id_note_task`
    FOREIGN KEY (`ID_TASK`)
    REFERENCES `todo`.`TASK` (`ID_TASK`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `id_note_user`
    FOREIGN KEY (`ID_USER`)
    REFERENCES `todo`.`USER` (`ID_USER`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `todo`.`ROLE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`ROLE` (
  `ID_ROLE` BIGINT(20) NOT NULL,
  `ROLE_NAME` VARCHAR(255) NOT NULL,
  PRIMARY KEY (`ID_ROLE`),
  UNIQUE INDEX `ROLE_ID_UNIQUE` (`ID_ROLE` ASC),
  UNIQUE INDEX `ROLE_NAME_UNIQUE` (`ROLE_NAME` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `todo`.`USER_ROLE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`USER_ROLE` (
  `ID_USER` BIGINT(20) NOT NULL,
  `ID_ROLE` BIGINT(20) NOT NULL,
  INDEX `ID_ROLE_idx` (`ID_ROLE` ASC),
  INDEX `ID_USER_idx` (`ID_USER` ASC),
  CONSTRAINT `FK_PK_ROLE_ID`
    FOREIGN KEY (`ID_ROLE`)
    REFERENCES `todo`.`ROLE` (`ID_ROLE`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_PK_USER_ID`
    FOREIGN KEY (`ID_USER`)
    REFERENCES `todo`.`USER` (`ID_USER`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `todo`.`USER_TASK`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `todo`.`USER_TASK` (
  `ID_USER` BIGINT(20) NOT NULL,
  `ID_TASK` BIGINT(20) NOT NULL,
  `URGENT` BIT(1) NULL DEFAULT NULL,
  PRIMARY KEY (`ID_USER`, `ID_TASK`),
  INDEX `task_id_idx` (`ID_TASK` ASC),
  CONSTRAINT `id_task`
    FOREIGN KEY (`ID_TASK`)
    REFERENCES `todo`.`TASK` (`ID_TASK`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `user_id`
    FOREIGN KEY (`ID_USER`)
    REFERENCES `todo`.`USER` (`ID_USER`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
