package cz.toho.security.filter;

import cz.toho.security.TokenAuthenticationService;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.filter.GenericFilterBean;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;

/**
 * Filter for transparent authentication which can go with all REST requests. Token is read from custom header
 * <p>
 * Created by tomasholicky
 */
public class StatelessAuthenticationFilter extends GenericFilterBean {
    /**
     * token authentication service
     */
    private TokenAuthenticationService tokenAuthenticationService;

    public StatelessAuthenticationFilter(TokenAuthenticationService tokenAuthenticationService) {
        this.tokenAuthenticationService = tokenAuthenticationService;
    }

    /**
     * Do filer
     *
     * @param req   request
     * @param res   response
     * @param chain filter chain
     * @throws IOException
     * @throws ServletException
     */
    @Override
    public void doFilter(ServletRequest req, ServletResponse res, FilterChain chain) throws IOException, ServletException {
        // read authentication object from header
        Authentication authentication = tokenAuthenticationService.getAuthentication((HttpServletRequest) req);
        // set authentication to security context
        SecurityContextHolder.getContext().setAuthentication(authentication);

        chain.doFilter(req, res);
    }
}
