package cz.toho.security.filter;

import com.fasterxml.jackson.databind.ObjectMapper;
import cz.toho.exception.TodoListException;
import cz.toho.service.UserService;
import org.springframework.security.web.util.matcher.AntPathRequestMatcher;
import org.springframework.web.filter.GenericFilterBean;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * Filter for stateless register
 * <p>
 * Created by tomasholicky
 */
public class StatelessRegisterFilter extends GenericFilterBean {
    /**
     * ant path request matcher
     */
    private final AntPathRequestMatcher antPathRequestMatcher;
    /**
     * user service
     */
    private UserService userService;

    public StatelessRegisterFilter(String urlMapping, UserService userService) {
        this.antPathRequestMatcher = new AntPathRequestMatcher(urlMapping);
        this.userService = userService;
    }

    @Override
    public void doFilter(ServletRequest req, ServletResponse res, FilterChain chain) throws IOException, ServletException {
        if (antPathRequestMatcher.matches((HttpServletRequest) req)) {
            final Credentials newUser = new ObjectMapper().readValue(req.getInputStream(), Credentials.class);
            try {
                final boolean userExists = this.userService.existsUser(newUser.getUsername());
                if (userExists) {
                    HttpServletResponse response = (HttpServletResponse) res;
                    response.setStatus(HttpServletResponse.SC_CONFLICT);
                    response.getWriter().write(newUser.getUsername());
                    response.getWriter().flush();
                    response.getWriter().close();
                    return;
                } else {
                    this.userService.createUser(newUser.getUsername(), newUser.getPassword());
                }
            } catch (TodoListException e) {
                HttpServletResponse response = (HttpServletResponse) res;
                response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
                return;
            }
            return;
        }

        chain.doFilter(req, res);
    }
}
