package cz.toho.service;

import cz.toho.exception.TodoListException;
import cz.toho.model.Note;
import cz.toho.model.TaskFile;
import cz.toho.model.TaskFileInfo;
import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.util.List;

/**
 * File service
 * <p>
 * Created by tomasholicky
 */

public interface FileService {
    /**
     * Create file given user and task
     *
     * @param currentUserName current user name
     * @param idTask          id task
     * @param file            file
     * @return id
     * @throws TodoListException
     */
    long saveFile(final String currentUserName, final long idTask, final MultipartFile file) throws TodoListException;

    /**
     * Load files info by given task
     *
     * @param idTask id task
     * @return list of {@link Note}
     * @throws TodoListException
     */
    List<TaskFileInfo> loadFilesInfo(final Long idTask) throws TodoListException;

    /**
     * Load file by given id file and task id
     *
     * @param idFile id file
     * @param idTask id task
     * @return {@link InputStream}
     * @throws TodoListException
     */
    TaskFile loadFile(final Long idFile, final Long idTask) throws TodoListException;

    /**
     * Delete file by given id file and task id
     *
     * @param idFile id file
     * @param idTask id task
     * @throws TodoListException
     */
    void deleteFile(final Long idFile, final Long idTask) throws TodoListException;
}
