package cz.toho.service;

import cz.toho.exception.TodoListException;
import cz.toho.model.Task;
import cz.toho.model.TaskStatusEnum;

import java.util.List;

/**
 * Task service
 * <p>
 * Created by tomasholicky
 */

public interface TaskService {
    /**
     * Load task by given user name and id task
     *
     * @param userName user name
     * @param idTask   id of task
     * @return {@link Task}
     * @throws TodoListException
     */
    Task loadTask(final String userName, final Long idTask) throws TodoListException;

    /**
     * Load task by status
     *
     * @param userName   user name
     * @param taskStatus task status
     * @return list of {@link Task}
     * @throws TodoListException
     */
    List<Task> loadTasksByStatus(final String userName, final TaskStatusEnum taskStatus) throws TodoListException;

    /**
     * Load urgent task
     *
     * @param userName user name
     * @return list of {@link Task}
     * @throws TodoListException
     */
    List<Task> loadUrgentTasks(final String userName) throws TodoListException;

    /**
     * Add task
     *
     * @param name        name
     * @param description description
     * @param userName    user name
     * @return id of created task
     * @throws TodoListException
     */
    long addTask(final String name, final String description, String userName) throws TodoListException;

    /**
     * Delete task
     *
     * @param userName user name
     * @param idTask   id of task
     * @throws TodoListException
     */
    void deleteTask(final String userName, final long idTask) throws TodoListException;

    /**
     * Update task status
     *
     * @param userName   user name
     * @param idTask     id of task
     * @param taskStatus task status
     * @throws TodoListException
     */
    void updateTaskStatus(final String userName, final long idTask, final TaskStatusEnum taskStatus) throws TodoListException;

    /**
     * Mark task as urgent
     *
     * @param userName user name
     * @param idTask   id of task
     * @param urgent   flag, that task is urgent
     * @throws TodoListException
     */
    void markUrgentTask(final String userName, final long idTask, final boolean urgent) throws TodoListException;

    /**
     * Share task
     *
     * @param currentUserName current user name
     * @param shareName       share name
     * @param idTask          id of task
     * @throws TodoListException
     */
    void shareTask(final String currentUserName, final String shareName, final long idTask) throws TodoListException;
}
