package cz.toho.service.impl;

import cz.toho.dao.FileDao;
import cz.toho.dao.UserDao;
import cz.toho.exception.TodoListDaoException;
import cz.toho.exception.TodoListException;
import cz.toho.model.TaskFile;
import cz.toho.model.TaskFileInfo;
import cz.toho.model.User;
import cz.toho.service.FileService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * Implementation of file service
 * <p>
 * Created by tomasholicky
 */

@Service
@Transactional("todoListTransactionManager")
public class FileServiceImpl implements FileService {
    /**
     * user dao
     */
    @Autowired
    private UserDao userDao;
    /**
     * file dao
     */
    @Autowired
    private FileDao fileDao;
    /**
     * logger
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(FileServiceImpl.class);

    @Override
    public long saveFile(final String currentUserName, final long idTask, final MultipartFile file) throws TodoListException {
        try {
            final User currentUser = this.userDao.getUser(currentUserName);
            return fileDao.createFile(idTask, currentUser.getUserId(), file.getOriginalFilename(), file.getContentType(), file.getInputStream());
        } catch (IOException e) {
            LOGGER.error("Error while working with file", e);
            throw new TodoListException(e);
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }

    @Override
    public List<TaskFileInfo> loadFilesInfo(final Long idTask) throws TodoListException {
        try {
            return this.fileDao.getFilesInfoByTask(idTask);
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }

    @Override
    public TaskFile loadFile(final Long idFile, final Long idTask) throws TodoListException {
        try {
            return this.fileDao.loadFile(idFile, idTask);
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }

    @Override
    public void deleteFile(Long idFile, Long idTask) throws TodoListException {
        try {
            this.fileDao.deleteFile(idFile, idTask);
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }
}
