package cz.toho.service.impl;

import cz.toho.dao.NoteDao;
import cz.toho.dao.TaskDao;
import cz.toho.dao.UserDao;
import cz.toho.exception.TodoListDaoException;
import cz.toho.exception.TodoListException;
import cz.toho.model.Note;
import cz.toho.model.Task;
import cz.toho.model.User;
import cz.toho.service.NoteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Implementation of note service
 * <p>
 * Created by tomasholicky
 */
@Service
@Transactional("todoListTransactionManager")
public class NoteServiceImpl implements NoteService {
    /**
     * user dao
     */
    @Autowired
    private UserDao userDao;
    /**
     * note dao
     */
    @Autowired
    private NoteDao noteDao;
    /**
     * task dao
     */
    @Autowired
    private TaskDao taskDao;

    @Override
    public long createNote(String currentUserName, long idTask, String note) throws TodoListException {
        try {
            final User currentUser = this.userDao.getUser(currentUserName);
            return this.noteDao.createNote(idTask, currentUser.getUserId(), note);
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }

    @Override
    public List<Note> loadNotesByTask(String userName, Long idTask) throws TodoListException {
        try {
            final User currentUser = this.userDao.getUser(userName);
            if (currentUser != null) {
                final Task task = this.taskDao.getTask(idTask, currentUser.getUserId());
                if (task != null) {
                    return this.noteDao.getNotesByTask(idTask);
                }
            }
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }

        return null;
    }
}
