package cz.toho.service.impl;

import cz.toho.dao.UserDao;
import cz.toho.exception.TodoListDaoException;
import cz.toho.exception.TodoListException;
import cz.toho.model.User;
import cz.toho.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * Implementation of user service
 * <p>
 * Created by tomasholicky
 */
@Service
@Transactional("todoListTransactionManager")
public class UserServiceImpl implements UserService {
    /**
     * user dao
     */
    @Autowired
    private UserDao userDao;

    @Override
    public long createUser(final String userName, final String password) throws TodoListException {
        try {
            final long idUser = this.userDao.createUser(userName, password);
            this.userDao.createUserRole(idUser);
            return idUser;
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }

    @Override
    public boolean existsUser(final String userName) throws TodoListException {
        try {
            final int count = this.userDao.existsUser(userName);
            if (count == 1) {
                return true;
            }
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
        return false;
    }

    @Override
    public boolean checkRightForGivenTask(String userName, Long idTask) throws TodoListException {
        try {
            final User currentUser = this.userDao.getUser(userName);
            return this.userDao.checkRightForGivenTask(currentUser.getUserId(), idTask);
        } catch (TodoListDaoException e) {
            throw new TodoListException(e);
        }
    }
}
