/**
 * Created by tomasholicky
 */

module.exports = function (grunt) {
    "use strict";

    // Load all grunt tasks
    require('load-grunt-tasks')(grunt);

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),

        // Project settings
        cfg: {
            src: 'src', //application source code folder
            dist: 'target/dist', //application distribution folder
            test: 'test', //tests source folder,
            bower: 'bower_components',
            war: '../todo-api/target/todo-api-exploded.war' //exploded war path for idea
        },

        // Clean
        clean: {
            dist: ['<%=cfg.dist%>']
        },

        // Templates
        ngtemplates: {
            build: {
                options: {
                    module: 'cz.toho.templates',
                    standalone: true,
                    htmlmin: {
                        collapseWhitespace: true,
                        collapseBooleanAttributes: true,
                        removeComments: true
                    },
                    url: function (url) {
                        return url.replace('src/app/', '');
                    }
                },
                src: [
                    '<%=cfg.src%>/**/*.html'
                ],
                dest: '<%=cfg.dist%>/js/templates.js'
            }
        },

        // Javascript
        ngAnnotate: {
            build: {
                files: [
                    {
                        src: [
                            '<%=cfg.src%>/**/*.js'
                        ],
                        dest: '<%=cfg.dist%>/js/application.js'
                    }
                ]
            }
        },

        // Validate files using jshint
        jshint: {
            options: {
                undef: true,
                unused: 'vars',
                nonew: true,
                nonbsp: true,
                bitwise: true,
                reporter: require('jshint-stylish')
            },
            grunt: {
                options: {
                    node: true
                },
                files: {
                    src: ["Gruntfile.js"]
                }
            },
            sources: {
                options: {
                    browser: true,
                    sub: true,
                    globals: {
                        angular: true,
                        console: true,
                        cs: true,
                        moment: true
                    }
                },
                files: {
                    src: [
                        '<%=cfg.src%>/**/*.js'
                    ]
                }
            },
            test: {
                options: {
                    sub: true,
                    globalstrict: true,
                    globals: {
                        console: true,
                        moment: true,
                        angular: true,
                        jasmine: true,
                        describe: true,
                        it: true,
                        beforeEach: true,
                        expect: true,
                        module: true,
                        inject: true,
                        spyOn: true
                    }
                },
                files: {
                    src: ['<%= cfg.test %>/**/*.js']
                }
            }
        },


        concat: {
            options: {
                separator: '\n'
            },
            lib: {
                src: [
                    // Jquery
                    '<%=cfg.bower%>/jquery/dist/jquery.min.js',
                    '<%=cfg.bower%>/jquery-ui/ui/jquery-ui.js',

                    // Angular
                    '<%=cfg.bower%>/angular/angular.js',
                    '<%=cfg.bower%>/angular-bootstrap/ui-bootstrap-tpls.js',
                    '<%=cfg.bower%>/angular-cookies/angular-cookies.min.js',
                    '<%=cfg.bower%>/angular-ui-router/release/angular-ui-router.min.js',
                    '<%=cfg.bower%>/angular-ui-tree/dist/angular-ui-tree.js',
                    '<%=cfg.bower%>/angular-aria/angular-aria.js',
                    '<%=cfg.bower%>/angular-animate/angular-animate.min.js',
                    '<%=cfg.bower%>/angular-resource/angular-resource.min.js',
                    '<%=cfg.bower%>/bootstrap/dist/js/bootstrap.min.js',
                    '<%=cfg.bower%>/angular-jwt/dist/angular-jwt.min.js',
                    '<%=cfg.bower%>/angular-webstorage/angular-webstorage.min.js',
                    '<%=cfg.bower%>/angular-messages/angular-messages.min.js',
                    '<%=cfg.bower%>/angular-ui-notification/dist/angular-ui-notification.min.js',
                    '<%=cfg.bower%>/ng-file-upload/ng-file-upload.min.js',

                    // Languages
                    '<%=cfg.bower%>/angular-i18n/angular-locale_cs.js'
                ],
                dest: '<%=cfg.dist%>/js/lib.js'
            },
            css: {
                src: [
                    '<%=cfg.bower%>/bootstrap/dist/css/bootstrap.min.css',
                    '<%=cfg.src%>/app/css/main.css',
                    '<%=cfg.bower%>/font-awesome/css/font-awesome.min.css',
                    '<%=cfg.bower%>/angular-ui-tree/dist/angular-ui-tree.min.css',
                    '<%=cfg.bower%>/angular-ui-notification/dist/angular-ui-notification.min.css'
                ],
                dest: '<%=cfg.dist%>/lib.css'
            }
        },

        copy: {
            assets: {
                files: [
                    {
                        expand: true,
                        dest: '<%=cfg.dist%>/img',
                        cwd: '<%=cfg.src%>/app/img',
                        src: ['profile.png', 'AngularJS-Shield-medium.png', 'spring.png', 'REST.png', 'noTask.png']
                    },
                    {
                        expand: true,
                        dest: '<%=cfg.dist%>/fonts',
                        cwd: '<%=cfg.bower%>/bootstrap/fonts',
                        src: '**'
                    },
                    {
                        expand: true,
                        dest: '<%=cfg.dist%>/fonts',
                        cwd: '<%=cfg.bower%>/font-awesome/fonts',
                        src: '**'
                    },
                    {
                        expand: true,
                        dest: '<%=cfg.dist%>/',
                        cwd: '<%=cfg.src%>/app/',
                        src: ['index.html']
                    }
                ]
            },
            release: {},
            idea: {
                files: [{
                    expand: true,
                    cwd: '<%=cfg.dist%>',
                    dest: '<%=cfg.war%>',
                    src: ['**']
                }, {
                    expand: true,
                    cwd: '<%=cfg.tmp%>/js',
                    dest: '<%=cfg.war%>',
                    src: ['**']
                }]
            }
        }
    });

    grunt.registerTask('javascript', ['jshint:sources', 'ngAnnotate:build', 'concat']);

    grunt.registerTask('default', ['jshint:grunt', 'clean', 'javascript', 'ngtemplates', 'copy:assets']);
    grunt.registerTask('idea', ['jshint:grunt', 'clean', 'javascript', 'ngtemplates', 'copy:assets', 'copy:idea']);
};