/**
 * Created by tomasholicky
 */
(function () {
    'use strict';

    var todoClient = angular.module('cz.toho.todoClient', [
        'ui-notification',
        'ui.router',
        'cz.toho.taskResourceFactory',
        'cz.toho.userResourceFactory',
        'cz.toho.auth.directives',
        'cz.toho.common.directives',
        'cz.toho.main',
        'cz.toho.templates',
        'cz.toho.home',
        'cz.toho.task',
        'cz.toho.login',
        'cz.toho.accountInfo',
        'cz.toho.registration',
        'ngResource',
        'ngMessages',
        'cz.toho.auth.stateRouter'
    ]).constant('API_URI', 'http://localhost:8080/api');

    todoClient.config(function (authServiceSettingsProvider, API_URI) {
        authServiceSettingsProvider.setLoginUrl(API_URI + '/login');
        authServiceSettingsProvider.setTokenRenewUrl(API_URI + '/renew');
    }).constant('TASK_STATES', {
        urgent: 'URGENT',
        todo: 'TODO',
        done: 'DONE'
    }).constant('EVENTS', {
        loginSuccess: 'cz.toho.auth:loginSuccess',
        loginFailed: 'cz.toho.auth:loginFailed',
        permissionError: 'cz.toho.auth:permissionError',
        changedState: 'cz.toho.auth:changedState'
    }).config(['$stateProvider', '$urlRouterProvider', '$httpProvider', function ($stateProvider, $urlRouterProvider) {
        $urlRouterProvider.otherwise('/');

        $stateProvider.state('anon', {
            abstract: true,
            template: "<ui-view/>",
            data: {
                access: 'access.anon'
            }
        }).state('anon.home', {
            url: '/',
            templateUrl: 'modules/home/home.html',
            controller: 'homeController',
            controllerAs: 'homeCtrl'
        }).state('anon.login', {
            url: '/login',
            templateUrl: 'modules/login/login.html',
            controller: 'loginController',
            controllerAs: 'loginCtrl'
        }).state('anon.registration', {
                url: '/registration',
                templateUrl: 'modules/registration/registration.html',
                controller: 'registrationController',
                controllerAs: 'registrationCtrl'
            }
        ).state('anon.error', {
            abstract: true,
            templateUrl: "modules/error/error.html",
            controller: function ($state, $scope) {
                $scope.data = $state.current.data;
            }
        }).state('anon.error.403', {
            data: {
                title: 'Neoprávněný přístup'
            }
        }).state('anon.error.500', {
            data: {
                title: 'Chyba na straně serveru'
            }
        });

        $stateProvider.state('user', {
            abstract: true,
            template: "<ui-view/>",
            data: {
                access: 'access.user',
                authRoles: ['ROLE_USER']
            }
        }).state('user.tasks', {
            url: '/tasks',
            controllerAs: 'taskListCtrl',
            controller: 'taskListController',
            templateUrl: 'modules/task/taskList.html'
        }).state('user.tasks.detail', {
            url: '^/tasks/:id',
            views: {
                '@': {
                    templateUrl: 'modules/task/detail/taskDetail.html',
                    controller: 'taskDetailController',
                    controllerAs: 'taskDetailCtrl'
                }
            }
        });

        $stateProvider.state('accountInfo', {
            url: '/account',
            controller: 'accountInfoController',
            controllerAs: 'accountInfo',
            templateUrl: 'modules/accountInfo/accountInfo.html',
            data: {
                access: 'access.user',
                authRoles: ['ROLE_USER']
            }
        });

    }]).run(function ($rootScope, $state, EVENTS) {
        function error403() {
            $state.go('anon.error.403');
        }

        $rootScope.$on(EVENTS.permissionError, error403);
    }).config(function (NotificationProvider) {
        NotificationProvider.setOptions({
            delay: 10000,
            startTop: 50,
            startRight: 10,
            verticalSpacing: 20,
            horizontalSpacing: 20,
            positionX: 'right',
            positionY: 'top'
        });
    });
})();
