/**
 * Created by tomasholicky
 */
(function () {
    'use strict';

    function tokenInterceptor(authTokenStore, authServiceSettings) {
        return {
            request: function (config) {
                config.headers = config.headers || {};
                if (authTokenStore.info.token) {
                    config.headers[authServiceSettings.tokenHeaderName] = authTokenStore.info.token;
                }
                return config;
            }
        };
    }

    function responseErrorInterceptor($injector) {
        return {
            responseError: function (response) {
                return $injector.invoke(function (authServiceSettings, authService, $q, $state) {
                    if (response.status === 401) {
                        if ($state.current === authServiceSettings.urls.login) {
                            return $q.reject(response);
                        }
                        $state.go('anon.login');
                        authService.clearAuth();
                        return $q.reject(response);
                    } else if (response.status === 403) {
                        $state.go('anon.error.403');
                        return $q.reject(response);
                    } else if (response.status === 500) {
                        $state.go('anon.error.500');
                        return $q.reject(response);
                    }
                    return $q.reject(response);
                });
            }
        };
    }

    angular.module('cz.toho.auth', ['cz.toho.auth.service'])
        .config(function ($httpProvider) {
            $httpProvider.interceptors.push(tokenInterceptor);
            $httpProvider.interceptors.push(responseErrorInterceptor);
        });

})();
