/**
 * Created by tomasholicky
 */
(function () {
    'use strict';

    var stateAuthService = function ($rootScope, $state, authService, EVENTS) {

        this.isPublicVisible = function (state) {
            if (!state.hasOwnProperty('data')) {
                return true;
            }

            var mustBeLogged = state.data.authLogged ||
                (state.data.authRoles && angular.isArray(state.data.authRoles) && state.data.authRoles.length > 0);

            return !mustBeLogged;
        };

        this.hasPermissionForState = function (state) {
            if (state.data.authRoles) {
                if (!authService.hasSomeRole(state.data.authRoles)) {
                    return false;
                }
            }

            return true;
        };

        this.checkPermissionWhenStateChangeStarted = function (event, toState) {

            if (this.isPublicVisible(toState)) {
                return;
            }

            if (authService.isAuthenticated()) {
                this.checkPermissionsAndBroadcastIfError(toState, event);
            } else {
                event.preventDefault(); // stop routing
                $state.go('anon.login');
            }
        };

        this.checkPermissionsAndBroadcastIfError = function (state, event) {
            if (!this.hasPermissionForState(state)) {
                if (event) {
                    event.preventDefault(); // stop routing
                }
                $rootScope.$broadcast(EVENTS.permissionError, 'User has not permissions to ' + state.name);
                return false;
            }

            return true;
        };
    };

    angular.module('cz.toho.auth.stateRouter',
        ['ui.router', 'cz.toho.auth.service'])
        .service('stateAuth', stateAuthService)
        .run(function ($rootScope, stateAuth) {
            $rootScope.$on('$stateChangeStart', stateAuth.checkPermissionWhenStateChangeStarted.bind(stateAuth));
        });

})();