/**
 * Created by tomasholicky
 */
(function () {
    'use strict';

    angular.module('cz.toho.task.detail', ['ngFileUpload']).controller('taskDetailController', ['$scope', '$state', '$stateParams', 'ApiTask', 'API_URI', 'TASK_STATES', 'Upload', '$timeout', 'Notification', '$http', function ($scope, $state, $stateParams, ApiTask, API_URI, TASK_STATES, Upload, $timeout, Notification, $http) {
        this.TASK_STATES = TASK_STATES;
        this.task = ApiTask.TaskId.get($stateParams);

        this.notes = ApiTask.Notes.query($stateParams);

        this.files = ApiTask.Files.query($stateParams);

        this.addNote = function () {
            ApiTask.Notes.save({id: $stateParams.id}, this.note).$promise.then(function (data) {
                $scope.$broadcast('cz.toho.task:addNote');
            });
        };

        this.uploadFile = function (file) {
            file.upload = Upload.upload({
                url: API_URI + '/tasks/' + this.task.idTask + '/files',
                data: {file: file}
            });

            file.upload.then(function (response) {
                $timeout(function () {
                    $scope.$broadcast('cz.toho.task:reloadFiles');
                    Notification.success('<i class="fa fa-upload"></i> Soubor ' + file.name + ' byl nahrán.');
                });
            }, function (response) {
                if (response.status > 0)
                    this.errorMsg = response.status + ': ' + response.data;
            }, function (evt) {
                file.progress = Math.min(100, parseInt(100.0 * evt.loaded / evt.total));
            });
        };

        this.downloadFile = function (file) {
            $http({
                method: 'GET',
                url: API_URI + '/tasks/' + file.idTask + '/files/' + file.idFile,
                responseType: 'arraybuffer'
            }).success(function (data, status, headers) {
                headers = headers();

                var filename = headers['todo-filename'];
                var contentType = headers['content-type'];

                var linkElement = document.createElement('a');
                try {
                    var blob = new Blob([data], {type: contentType});
                    var url = window.URL.createObjectURL(blob);

                    linkElement.setAttribute('href', url);
                    linkElement.setAttribute("download", filename);

                    var clickEvent = new MouseEvent("click", {
                        "view": window,
                        "bubbles": true,
                        "cancelable": false
                    });
                    linkElement.dispatchEvent(clickEvent);
                } catch (ex) {
                }
            }).error(function (data) {
            });
        };

        this.deleteFile = function (file) {
            ApiTask.File.delete({idTask: file.idTask, idFile: file.idFile}).$promise.then(function (response) {
                $scope.$broadcast('cz.toho.task:reloadFiles');
                Notification.error('<i class="fa fa-trash-o"></i> Soubor ' + file.fileName + ' byl smazán.');
            });
        };

        $scope.$on('cz.toho.task:addNote', function (event, args) {
            this.notes = ApiTask.Notes.query($stateParams);
            this.note = null;
        }.bind(this));

        $scope.$on('cz.toho.task:reloadFiles', function (event, args) {
            this.files = ApiTask.Files.query($stateParams);
            this.taskFile = null;
        }.bind(this));

        $scope.$on('cz.toho.task:reloadDetailTask', function (event, args) {
            this.task = ApiTask.TaskId.get($stateParams);
        }.bind(this));
    }]);
})();